@@ -4,6 +4,7 @@
 #define OPENBLAS_ARCH_ARM 1
 #define OPENBLAS_C_GCC 1
 #define OPENBLAS___32BIT__ 1
+#define OPENBLAS_HAVE_C11 1
 #define OPENBLAS_PTHREAD_CREATE_FUNC pthread_create
 #define OPENBLAS_BUNDERSCORE _
 #define OPENBLAS_NEEDBUNDERSCORE 1
@@ -21,7 +22,7 @@
 #define OPENBLAS_L2_ASSOCIATIVE 4
 #define OPENBLAS_CHAR_CORENAME "ARMV7"
 #define OPENBLAS_GEMM_MULTITHREAD_THRESHOLD 4
-#define OPENBLAS_VERSION " OpenBLAS 0.3.10 "
+#define OPENBLAS_VERSION " OpenBLAS 0.3.12 "
 /*This is only for "make install" target.*/
 
 #if defined(OPENBLAS_OS_WINNT) || defined(OPENBLAS_OS_CYGWIN_NT) || defined(OPENBLAS_OS_INTERIX)
@@ -58,6 +59,11 @@ typedef long BLASLONG;
 typedef unsigned long BLASULONG;
 #endif
 
+#ifndef BFLOAT16
+#include <stdint.h>
+typedef uint16_t bfloat16;
+#endif
+
 #ifdef OPENBLAS_USE64BITINT
 typedef BLASLONG blasint;
 #else
